==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/BollingerBandWidthIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { BollingerBandWidthIndicatorStrategy } from "./BollingerBandWidthIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var BollingerBandWidthIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(BollingerBandWidthIndicator, _super);
    function BollingerBandWidthIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BollingerBandWidthIndicator.prototype.get_up = function () {
        return new BollingerBandWidthIndicatorStrategy();
    };
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "up", {
        get: function () {
            return this.get_up();
        },
        enumerable: false,
        configurable: true
    });
    BollingerBandWidthIndicator.prototype.get_u2 = function () {
        return BollingerBandWidthIndicator.$;
    };
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "u2", {
        get: function () {
            return this.get_u2();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "vb", {
        get: function () {
            return typeGetValue(this.c(BollingerBandWidthIndicator.ve));
        },
        set: function (a) {
            this.h(BollingerBandWidthIndicator.ve, a);
        },
        enumerable: false,
        configurable: true
    });
    BollingerBandWidthIndicator.prototype.uv = function () {
        return this.vb;
    };
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "va", {
        get: function () {
            return this.c(BollingerBandWidthIndicator.vd);
        },
        set: function (a) {
            this.h(BollingerBandWidthIndicator.vd, a);
        },
        enumerable: false,
        configurable: true
    });
    BollingerBandWidthIndicator.prototype.ut = function () {
        return this.va;
    };
    BollingerBandWidthIndicator.$t = markType(BollingerBandWidthIndicator, 'BollingerBandWidthIndicator', StrategyBasedIndicator.$);
    BollingerBandWidthIndicator.ve = StrategyBasedIndicator.u7(20, BollingerBandWidthIndicator.$);
    BollingerBandWidthIndicator.vd = StrategyBasedIndicator.u6(2, BollingerBandWidthIndicator.$);
    return BollingerBandWidthIndicator;
}(StrategyBasedIndicator));
export { BollingerBandWidthIndicator };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/BollingerBandWidthIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { BollingerBandWidthIndicatorStrategy } from "./BollingerBandWidthIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var BollingerBandWidthIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(BollingerBandWidthIndicator, _super);
    function BollingerBandWidthIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BollingerBandWidthIndicator.prototype.get_yy = function () {
        return new BollingerBandWidthIndicatorStrategy();
    };
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    BollingerBandWidthIndicator.prototype.get_zb = function () {
        return BollingerBandWidthIndicator.$;
    };
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "zk", {
        get: function () {
            return typeGetValue(this.c(BollingerBandWidthIndicator.zn));
        },
        set: function (a) {
            this.h(BollingerBandWidthIndicator.zn, a);
        },
        enumerable: false,
        configurable: true
    });
    BollingerBandWidthIndicator.prototype.y4 = function () {
        return this.zk;
    };
    Object.defineProperty(BollingerBandWidthIndicator.prototype, "zj", {
        get: function () {
            return this.c(BollingerBandWidthIndicator.zm);
        },
        set: function (a) {
            this.h(BollingerBandWidthIndicator.zm, a);
        },
        enumerable: false,
        configurable: true
    });
    BollingerBandWidthIndicator.prototype.y2 = function () {
        return this.zj;
    };
    BollingerBandWidthIndicator.$t = markType(BollingerBandWidthIndicator, 'BollingerBandWidthIndicator', StrategyBasedIndicator.$);
    BollingerBandWidthIndicator.zn = StrategyBasedIndicator.zg(20, BollingerBandWidthIndicator.$);
    BollingerBandWidthIndicator.zm = StrategyBasedIndicator.zf(2, BollingerBandWidthIndicator.$);
    return BollingerBandWidthIndicator;
}(StrategyBasedIndicator));
export { BollingerBandWidthIndicator };
